==================
Welcome to PyLoan!
==================
PyLoan is a Python package designed to provide a lightweight and flexible tool to perform mortgage/loan calculations, including:

* Calculate payment amount to fully amortize a mortgage/loan over its term.
* Amortize a mortgage/loan based on the specified payment schedule.
* Consider ad-hoc or periodic special principal repayments during the mortgage/loan amortization schedule.
* Calculate interest payments using either 30/360 methods or actual methods.
* Consider interest-only payment periods.

Installation
============
PyLoan is distributed on PyPI and can be installed with `pip`::

  $ pip install pyloan

For more information, read the documentation on `installing the package <https://pyloan.readthedocs.io/en/latest/installation.html>`_.

Quickstart
==========
Read the `Quickstart <https://pyloan.readthedocs.io/en/latest/quickstart.html>`_ guide to see illustrative examples on how to get started using PyLoan to perform mortgage/loan calculations.

Support
=======
Report bugs via the bug tracker on `GitHub <https://github.com/sudo-dakix/pyloan/issues>`_.

License
=======
PyLoan is licensed under the `MIT License <https://github.com/sudo-dakix/pyloan/blob/master/LICENSE>`_.
